# minecraft-launcher-cmd

Start Minecraft from commandline

Usage:  
`minecraft-launcher-cmd --username {Username} --password {Password}`

Run minecraft-launcher-cmd --help to get a list of all aviable options.

This program is powered [minecraft-launcher-lib](https://pypi.org/project/minecraft-launcher-lib).
